====================================================
``psyclone.tests.psyir.frontend.fparser2_call_test``
====================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_call_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_call_test
